/*
		  Endeavour Mark II API Master Header File
 */

#ifndef LIBENDEAVOUR2_H
#define LIBENDEAVOUR2_H

#include <glib.h>
#include "edv_types.h"			/* Typedefs & Enums */
#include "edv_cfg_list.h"		/* Configuration List */
#include "edv_context.h"		/* Context */
#include "edv_date.h"			/* Date & Time */
#include "edv_device.h"			/* Devices */
#include "edv_device_get.h"		/* Devices Fetching & Matching */
#include "edv_device_mount.h"		/* Device Mounting, Unmounting, and Ejecting */
/* edv_devices_list.h is private */
#include "edv_get.h"			/* Cfg Fetching */
#include "edv_help.h"			/* Help Browser & Help Displaying */
#include "edv_history.h"		/* History Event Logging */
#include "edv_id.h"			/* User and Group ID */
#include "edv_id_get.h"			/* User and Group ID Fetching & Matching */
/* edv_id_list.h is private */
#include "edv_message.h"		/* Message Output & Play Sound */
#include "edv_mime_type.h"		/* MIME Types */
#include "edv_mime_type_get.h"		/* MIME Types Fetching & Matching */
#include "edv_mime_type_install.h"	/* MIME Types Installing */
/* edv_mime_types_list.h is private */
#include "edv_notify.h"			/* Event Notifying */
#include "edv_open.h"			/* Object Opening */
#include "edv_recycle.h"			/* Recycle, Recover, and Purge */
#include "edv_utils.h"			/* Utilities */
#include "edv_window.h"			/* Window Creation & Mapping */

#endif	/* LIBENDEAVOUR2_H */
